summaryrefslogtreecommitdiffstats
path: root/kplato/kptproject.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /kplato/kptproject.h
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'kplato/kptproject.h')
-rw-r--r--kplato/kptproject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kplato/kptproject.h b/kplato/kptproject.h
index 14f03384..d0dd1eb9 100644
--- a/kplato/kptproject.h
+++ b/kplato/kptproject.h
@@ -223,11 +223,11 @@ public:
Accounts &accounts() { return m_accounts; }
/// Set current schedule to schedule with identity id, for me and my tqchildren
virtual void setCurrentSchedule(long id);
/// Create new schedule with unique id.
MainSchedule *createSchedule(TQString name, Schedule::Type type);
/// Set parent schedule for my tqchildren
virtual void setParentSchedule(Schedule *sch);
protected:
@@ -267,7 +267,7 @@ private:
#ifndef NDEBUG
#include <tqcstring.h>
public:
- void printDebug(bool tqchildren, TQCString indent);
+ void printDebug(bool children, TQCString indent);
void printCalendarDebug(TQCString indent="");
#ifdef DEBUGPERT
static void pert_test();
@@ -223,11 +223,11 @@ public:
Accounts &accounts() { return m_accounts; }
- /// Set current schedule to schedule with identity id, for me and my tqchildren
+ /// Set current schedule to schedule with identity id, for me and my children
virtual void setCurrentSchedule(long id);
/// Create new schedule with unique id.
@@ -223,11 +223,11 @@ public:
/// Create new schedule with unique id.
MainSchedule *createSchedule(TQString name, Schedule::Type type);
- /// Set parent schedule for my tqchildren
+ /// Set parent schedule for my children
virtual void setParentSchedule(Schedule *sch);
protected: